import { StringCodec, connect, } from "nats";
export default class NatsAdaptor {
    options;
    nc;
    callbacks;
    sc;
    sub;
    constructor(options) {
        this.options = options;
        this.sc = StringCodec();
        this.callbacks = {};
    }
    async listen(serviceName) {
        this.nc = await connect(this.options);
        this.sub = this.nc.subscribe(`${serviceName}.*`);
        (async (sub) => {
            for await (const msg of sub) {
                const res = await this.callbacks[msg.subject](this.sc.decode(msg.data));
                msg.respond(this.sc.encode(res));
            }
        })(this.sub);
    }
    subscribe(subject, fn) {
        this.callbacks[subject] = fn;
    }
    async request(subject, req) {
        if (this.nc) {
            const msg = await this.nc.request(subject, this.sc.encode(req));
            return this.sc.decode(msg.data);
        }
        throw new Error("nats connection is not initialized");
    }
    async stop() {
        await this.nc?.drain();
    }
}
